@@ -22,29 +22,28 @@ from faker import Faker, exceptions
 from faker.contrib.pytest.plugin import DEFAULT_LOCALE, DEFAULT_SEED
 
 
-@pytest.fixture(scope='class')
+@pytest.fixture(scope="class")
 def _class_faker_with_foobar():
     _fake = Faker(locale=DEFAULT_LOCALE)
     _fake.add_provider(_FooBarProvider())
-    _fake.set_arguments('argument_group', 'param', 'Baz')
-    _fake.set_arguments('double', 'multi', 2)
+    _fake.set_arguments("argument_group", "param", "Baz")
+    _fake.set_arguments("double", "multi", 2)
     return _fake
 
 
 @pytest.fixture()
 def faker_with_foobar(request):
-    fake = request.getfixturevalue('_class_faker_with_foobar')
+    fake = request.getfixturevalue("_class_faker_with_foobar")
     seed = DEFAULT_SEED
-    if 'faker_seed' in request.fixturenames:
-        seed = request.getfixturevalue('faker_seed')
+    if "faker_seed" in request.fixturenames:
+        seed = request.getfixturevalue("faker_seed")
     fake.seed_instance(seed=seed)
     return fake
 
 
 class _FooBarProvider:
-
     def foo_bar(self, param: str = None) -> str:
-        return 'FooBar' + str(param) if param else 'FooBar'
+        return "FooBar" + str(param) if param else "FooBar"
 
     def test_integer(self, multi=1) -> int:
         return 1 * multi
@@ -55,10 +54,11 @@ class _FooBarProvider:
 
 class TestMiscProvider:
     """Test miscellaneous provider methods"""
+
     num_samples = 10
 
     def test_uuid4_str(self, faker, num_samples):
-        pattern: Pattern = re.compile(r'[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}')
+        pattern: Pattern = re.compile(r"[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}")
         for _ in range(num_samples):
             assert pattern.fullmatch(faker.uuid4())
 
@@ -83,19 +83,19 @@ class TestMiscProvider:
 
     def test_zip_invalid_file(self, faker):
         with pytest.raises(ValueError):
-            faker.zip(num_files='1')
+            faker.zip(num_files="1")
 
         with pytest.raises(ValueError):
             faker.zip(num_files=0)
 
         with pytest.raises(ValueError):
-            faker.zip(min_file_size='1')
+            faker.zip(min_file_size="1")
 
         with pytest.raises(ValueError):
             faker.zip(min_file_size=0)
 
         with pytest.raises(ValueError):
-            faker.zip(uncompressed_size='1')
+            faker.zip(uncompressed_size="1")
 
         with pytest.raises(ValueError):
             faker.zip(uncompressed_size=0)
@@ -109,7 +109,8 @@ class TestMiscProvider:
             # Will always fail because of bad size requirements
             with pytest.raises(AssertionError):
                 faker.zip(
-                    uncompressed_size=uncompressed_size, num_files=num_files,
+                    uncompressed_size=uncompressed_size,
+                    num_files=num_files,
                     min_file_size=min_file_size,
                 )
 
@@ -120,11 +121,12 @@ class TestMiscProvider:
             uncompressed_size = num_files * min_file_size
 
             zip_bytes = faker.zip(
-                uncompressed_size=uncompressed_size, num_files=num_files,
+                uncompressed_size=uncompressed_size,
+                num_files=num_files,
                 min_file_size=min_file_size,
             )
             zip_buffer = io.BytesIO(zip_bytes)
-            with zipfile.ZipFile(zip_buffer, 'r') as zip_handle:
+            with zipfile.ZipFile(zip_buffer, "r") as zip_handle:
                 # Verify zip archive is good
                 assert zip_handle.testzip() is None
 
@@ -149,11 +151,12 @@ class TestMiscProvider:
             uncompressed_size = num_files * min_file_size + expected_extra_bytes
 
             zip_bytes = faker.zip(
-                uncompressed_size=uncompressed_size, num_files=num_files,
+                uncompressed_size=uncompressed_size,
+                num_files=num_files,
                 min_file_size=min_file_size,
             )
             zip_buffer = io.BytesIO(zip_bytes)
-            with zipfile.ZipFile(zip_buffer, 'r') as zip_handle:
+            with zipfile.ZipFile(zip_buffer, "r") as zip_handle:
                 # Verify zip archive is good
                 assert zip_handle.testzip() is None
 
@@ -168,7 +171,7 @@ class TestMiscProvider:
                     assert info.file_size >= min_file_size
                     total_size += info.file_size
                     if info.file_size > min_file_size:
-                        extra_bytes += (info.file_size - min_file_size)
+                        extra_bytes += info.file_size - min_file_size
 
                 # The file sizes should sum up to the specified uncompressed size
                 # and the extra bytes counted must be equal to the one expected
@@ -180,22 +183,24 @@ class TestMiscProvider:
         min_file_size = 512
         uncompressed_size = 50 * 1024
         compression_mapping = [
-            ('deflate', zipfile.ZIP_DEFLATED),
-            ('gzip', zipfile.ZIP_DEFLATED),
-            ('gz', zipfile.ZIP_DEFLATED),
-            ('bzip2', zipfile.ZIP_BZIP2),
-            ('bz2', zipfile.ZIP_BZIP2),
-            ('lzma', zipfile.ZIP_LZMA),
-            ('xz', zipfile.ZIP_LZMA),
+            ("deflate", zipfile.ZIP_DEFLATED),
+            ("gzip", zipfile.ZIP_DEFLATED),
+            ("gz", zipfile.ZIP_DEFLATED),
+            ("bzip2", zipfile.ZIP_BZIP2),
+            ("bz2", zipfile.ZIP_BZIP2),
+            ("lzma", zipfile.ZIP_LZMA),
+            ("xz", zipfile.ZIP_LZMA),
             (None, zipfile.ZIP_STORED),
         ]
         for compression, compress_type in compression_mapping:
             zip_bytes = faker.zip(
-                uncompressed_size=uncompressed_size, num_files=num_files,
-                min_file_size=min_file_size, compression=compression,
+                uncompressed_size=uncompressed_size,
+                num_files=num_files,
+                min_file_size=min_file_size,
+                compression=compression,
             )
             zip_buffer = io.BytesIO(zip_bytes)
-            with zipfile.ZipFile(zip_buffer, 'r') as zip_handle:
+            with zipfile.ZipFile(zip_buffer, "r") as zip_handle:
                 # Verify zip archive is good
                 assert zip_handle.testzip() is None
 
@@ -205,19 +210,19 @@ class TestMiscProvider:
 
     def test_tar_invalid_file(self, faker):
         with pytest.raises(ValueError):
-            faker.tar(num_files='1')
+            faker.tar(num_files="1")
 
         with pytest.raises(ValueError):
             faker.tar(num_files=0)
 
         with pytest.raises(ValueError):
-            faker.tar(min_file_size='1')
+            faker.tar(min_file_size="1")
 
         with pytest.raises(ValueError):
             faker.tar(min_file_size=0)
 
         with pytest.raises(ValueError):
-            faker.tar(uncompressed_size='1')
+            faker.tar(uncompressed_size="1")
 
         with pytest.raises(ValueError):
             faker.tar(uncompressed_size=0)
@@ -231,7 +236,8 @@ class TestMiscProvider:
             # Will always fail because of conflicting size requirements
             with pytest.raises(AssertionError):
                 faker.tar(
-                    uncompressed_size=uncompressed_size, num_files=num_files,
+                    uncompressed_size=uncompressed_size,
+                    num_files=num_files,
                     min_file_size=min_file_size,
                 )
 
@@ -242,7 +248,8 @@ class TestMiscProvider:
             uncompressed_size = num_files * min_file_size
 
             tar_bytes = faker.tar(
-                uncompressed_size=uncompressed_size, num_files=num_files,
+                uncompressed_size=uncompressed_size,
+                num_files=num_files,
                 min_file_size=min_file_size,
             )
             tar_buffer = io.BytesIO(tar_bytes)
@@ -268,7 +275,8 @@ class TestMiscProvider:
             uncompressed_size = num_files * min_file_size + expected_extra_bytes
 
             tar_bytes = faker.tar(
-                uncompressed_size=uncompressed_size, num_files=num_files,
+                uncompressed_size=uncompressed_size,
+                num_files=num_files,
                 min_file_size=min_file_size,
             )
             tar_buffer = io.BytesIO(tar_bytes)
@@ -284,7 +292,7 @@ class TestMiscProvider:
                     assert member.size >= min_file_size
                     total_size += member.size
                     if member.size > min_file_size:
-                        extra_bytes += (member.size - min_file_size)
+                        extra_bytes += member.size - min_file_size
 
                 # The file sizes should sum up to the specified uncompressed size
                 # and the extra bytes counted should be the one we expect
@@ -296,19 +304,21 @@ class TestMiscProvider:
         min_file_size = 512
         uncompressed_size = 50 * 1024
         compression_mapping = [
-            ('gzip', 'r:gz'),
-            ('gz', 'r:gz'),
-            ('bzip2', 'r:bz2'),
-            ('bz2', 'r:bz2'),
-            ('lzma', 'r:xz'),
-            ('xz', 'r:xz'),
-            (None, 'r'),
+            ("gzip", "r:gz"),
+            ("gz", "r:gz"),
+            ("bzip2", "r:bz2"),
+            ("bz2", "r:bz2"),
+            ("lzma", "r:xz"),
+            ("xz", "r:xz"),
+            (None, "r"),
         ]
 
         for compression, read_mode in compression_mapping:
             tar_bytes = faker.tar(
-                uncompressed_size=uncompressed_size, num_files=num_files,
-                min_file_size=min_file_size, compression=compression,
+                uncompressed_size=uncompressed_size,
+                num_files=num_files,
+                min_file_size=min_file_size,
+                compression=compression,
             )
             tar_buffer = io.BytesIO(tar_bytes)
             with tarfile.open(fileobj=tar_buffer, mode=read_mode) as tar_handle:
@@ -316,14 +326,14 @@ class TestMiscProvider:
                 members = tar_handle.getmembers()
                 assert len(members) == num_files
 
-    @unittest.skipUnless(PIL, 'requires the Python Image Library')
+    @unittest.skipUnless(PIL, "requires the Python Image Library")
     def test_image(self, faker):
         img = PIL.Image.open(io.BytesIO(faker.image()))
         assert img.size == (256, 256)
-        assert img.format == 'PNG'
-        img = PIL.Image.open(io.BytesIO(faker.image(size=(2, 2), image_format='tiff')))
+        assert img.format == "PNG"
+        img = PIL.Image.open(io.BytesIO(faker.image(size=(2, 2), image_format="tiff")))
         assert img.size == (2, 2)
-        assert img.format == 'TIFF'
+        assert img.format == "TIFF"
 
     def test_image_no_pillow(self, faker):
         with patch.dict("sys.modules", {"PIL": None}):
@@ -334,7 +344,7 @@ class TestMiscProvider:
 
     def test_dsv_with_invalid_values(self, faker):
         with pytest.raises(ValueError):
-            faker.dsv(num_rows='1')
+            faker.dsv(num_rows="1")
 
         with pytest.raises(ValueError):
             faker.dsv(num_rows=0)
@@ -343,17 +353,17 @@ class TestMiscProvider:
             faker.dsv(header=None, data_columns=1)
 
         with pytest.raises(TypeError):
-            faker.dsv(header=1, data_columns=['???'])
+            faker.dsv(header=1, data_columns=["???"])
 
         with pytest.raises(ValueError):
-            faker.dsv(header=['Column 1', 'Column 2'], data_columns=['???'])
+            faker.dsv(header=["Column 1", "Column 2"], data_columns=["???"])
 
     def test_dsv_no_header(self, faker, num_samples):
-        data_columns = ['????', '?????']
+        data_columns = ["????", "?????"]
         for _ in range(num_samples):
             num_rows = faker.random.randint(1, 1000)
             dsv = faker.dsv(header=None, data_columns=data_columns, num_rows=num_rows)
-            reader = csv.reader(io.StringIO(dsv), dialect='faker-csv')
+            reader = csv.reader(io.StringIO(dsv), dialect="faker-csv")
 
             # Verify each row has correct number of columns
             for row in reader:
@@ -363,12 +373,12 @@ class TestMiscProvider:
             assert reader.line_num == num_rows
 
     def test_dsv_with_valid_header(self, faker, num_samples):
-        header = ['Column 1', 'Column 2']
-        data_columns = ['????', '?????']
+        header = ["Column 1", "Column 2"]
+        data_columns = ["????", "?????"]
         for _ in range(num_samples):
             num_rows = faker.random.randint(1, 1000)
             dsv = faker.dsv(header=header, data_columns=data_columns, num_rows=num_rows)
-            reader = csv.reader(io.StringIO(dsv), dialect='faker-csv')
+            reader = csv.reader(io.StringIO(dsv), dialect="faker-csv")
 
             # Verify each row has correct number of columns
             for row in reader:
@@ -378,15 +388,17 @@ class TestMiscProvider:
             assert reader.line_num == num_rows + 1
 
     def test_dsv_with_row_ids(self, faker, num_samples):
-        data_columns = ['????', '?????']
+        data_columns = ["????", "?????"]
         for _ in range(num_samples):
             counter = 0
             num_rows = faker.random.randint(1, 1000)
             dsv = faker.dsv(
-                header=None, data_columns=data_columns,
-                num_rows=num_rows, include_row_ids=True,
+                header=None,
+                data_columns=data_columns,
+                num_rows=num_rows,
+                include_row_ids=True,
             )
-            reader = csv.reader(io.StringIO(dsv), dialect='faker-csv')
+            reader = csv.reader(io.StringIO(dsv), dialect="faker-csv")
 
             # Verify each row has correct number of columns
             # and row ids increment correctly
@@ -400,8 +412,8 @@ class TestMiscProvider:
 
     def test_dsv_data_columns(self, faker):
         num_rows = 10
-        data_columns = ['{{name}}', '#??-####', '{{address}}', '{{phone_number}}']
-        with patch.object(faker['en_US'], 'pystr_format') as mock_pystr_format:
+        data_columns = ["{{name}}", "#??-####", "{{address}}", "{{phone_number}}"]
+        with patch.object(faker["en_US"], "pystr_format") as mock_pystr_format:
             mock_pystr_format.assert_not_called()
             faker.dsv(data_columns=data_columns, num_rows=num_rows)
 
@@ -416,17 +428,17 @@ class TestMiscProvider:
                 assert kwargs == {}
 
     def test_dsv_csvwriter_kwargs(self, faker):
-        data_keys = ['header', 'data_columns', 'num_rows', 'include_row_ids']
+        data_keys = ["header", "data_columns", "num_rows", "include_row_ids"]
         test_kwargs = {
-            'dialect': 'excel',
-            'header': ['Column 1', 'Column 2'],
-            'data_columns': ['????', '?????'],
-            'num_rows': 5,
-            'include_row_ids': True,
-            'delimiter': ';',
-            'invalid_kwarg': 'invalid_value',
+            "dialect": "excel",
+            "header": ["Column 1", "Column 2"],
+            "data_columns": ["????", "?????"],
+            "num_rows": 5,
+            "include_row_ids": True,
+            "delimiter": ";",
+            "invalid_kwarg": "invalid_value",
         }
-        with patch('faker.providers.misc.csv.writer') as mock_writer:
+        with patch("faker.providers.misc.csv.writer") as mock_writer:
             mock_writer.assert_not_called()
             faker.dsv(**test_kwargs)
             assert mock_writer.call_count == 1
@@ -441,60 +453,60 @@ class TestMiscProvider:
 
     def test_csv_helper_method(self, faker):
         kwargs = {
-            'header': ['Column 1', 'Column 2'],
-            'data_columns': ['????', '?????'],
-            'num_rows': 5,
-            'include_row_ids': True,
+            "header": ["Column 1", "Column 2"],
+            "data_columns": ["????", "?????"],
+            "num_rows": 5,
+            "include_row_ids": True,
         }
-        with patch('faker.providers.misc.Provider.dsv') as mock_dsv:
+        with patch("faker.providers.misc.Provider.dsv") as mock_dsv:
             mock_dsv.assert_not_called()
             faker.csv(**kwargs)
-            kwargs['delimiter'] = ','
+            kwargs["delimiter"] = ","
             mock_dsv.assert_called_once_with(**kwargs)
 
     def test_tsv_helper_method(self, faker):
         kwargs = {
-            'header': ['Column 1', 'Column 2'],
-            'data_columns': ['????', '?????'],
-            'num_rows': 5,
-            'include_row_ids': True,
+            "header": ["Column 1", "Column 2"],
+            "data_columns": ["????", "?????"],
+            "num_rows": 5,
+            "include_row_ids": True,
         }
-        with patch('faker.providers.misc.Provider.dsv') as mock_dsv:
+        with patch("faker.providers.misc.Provider.dsv") as mock_dsv:
             mock_dsv.assert_not_called()
             faker.tsv(**kwargs)
-            kwargs['delimiter'] = '\t'
+            kwargs["delimiter"] = "\t"
             mock_dsv.assert_called_once_with(**kwargs)
 
     def test_psv_helper_method(self, faker):
         kwargs = {
-            'header': ['Column 1', 'Column 2'],
-            'data_columns': ['????', '?????'],
-            'num_rows': 5,
-            'include_row_ids': True,
+            "header": ["Column 1", "Column 2"],
+            "data_columns": ["????", "?????"],
+            "num_rows": 5,
+            "include_row_ids": True,
         }
-        with patch('faker.providers.misc.Provider.dsv') as mock_dsv:
+        with patch("faker.providers.misc.Provider.dsv") as mock_dsv:
             mock_dsv.assert_not_called()
             faker.psv(**kwargs)
-            kwargs['delimiter'] = '|'
+            kwargs["delimiter"] = "|"
             mock_dsv.assert_called_once_with(**kwargs)
 
     def test_json_with_arguments(self, faker_with_foobar):
         kwargs = {
-            'data_columns': [
-                ('item1', '{{ foo_bar:argument_group }}'),
-                ('item2', 'foo_bar', {'param': 'BAZ'}),
+            "data_columns": [
+                ("item1", "{{ foo_bar:argument_group }}"),
+                ("item2", "foo_bar", {"param": "BAZ"}),
             ],
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data.get('item1') == 'FooBarBaz'
-        assert json_data.get('item2') == 'FooBarBAZ'
+        assert json_data.get("item1") == "FooBarBaz"
+        assert json_data.get("item2") == "FooBarBAZ"
 
     def test_json_multiple_rows(self, faker_with_foobar):
         kwargs = {
-            'data_columns': {'item': 'foo_bar'},
-            'num_rows': 2,
+            "data_columns": {"item": "foo_bar"},
+            "num_rows": 2,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
@@ -502,182 +514,185 @@ class TestMiscProvider:
 
     def test_json_passthrough_values(self, faker_with_foobar):
         kwargs = {
-            'data_columns': {
-                'item1': 1,
-                'item2': 1.0,
-                'item3': True,
-                'item4': '@fixed',
+            "data_columns": {
+                "item1": 1,
+                "item2": 1.0,
+                "item3": True,
+                "item4": "@fixed",
             },
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data['item1'] == 1
-        assert json_data['item2'] == 1.0
-        assert json_data['item3'] is True
-        assert json_data['item4'] == 'fixed'
+        assert json_data["item1"] == 1
+        assert json_data["item2"] == 1.0
+        assert json_data["item3"] is True
+        assert json_data["item4"] == "fixed"
 
     def test_json_type_integrity_int(self, faker_with_foobar):
         kwargs = {
-            'data_columns': {
-                'item1': 'test_integer',
-                'item2': 'test_integer:double',
+            "data_columns": {
+                "item1": "test_integer",
+                "item2": "test_integer:double",
             },
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
-        assert isinstance(json_data['item1'], int)
-        assert json_data['item2'] == 2
+        assert isinstance(json_data["item1"], int)
+        assert json_data["item2"] == 2
 
     def test_json_type_integrity_float(self, faker_with_foobar):
         kwargs = {
-            'data_columns': {
-                'item1': 'test_float',
-                'item2': 'test_float:double',
+            "data_columns": {
+                "item1": "test_float",
+                "item2": "test_float:double",
             },
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
-        assert isinstance(json_data['item1'], float)
-        assert json_data['item2'] == 2.2
+        assert isinstance(json_data["item1"], float)
+        assert json_data["item2"] == 2.2
 
     def test_json_invalid_data_columns(self, faker_with_foobar):
         kwargs = {
-            'data_columns': (('item', 'foo_bar'),),
-            'num_rows': 1,
+            "data_columns": (("item", "foo_bar"),),
+            "num_rows": 1,
         }
         with pytest.raises(TypeError) as excinfo:
             json.loads(faker_with_foobar.json(**kwargs))
-        assert str(excinfo.value) == 'Invalid data_columns type. Must be a dictionary or list'
+        assert str(excinfo.value) == "Invalid data_columns type. Must be a dictionary or list"
 
     def test_json_list_format_invalid_arguments_type(self, faker_with_foobar):
         kwargs = {
-            'data_columns': [('item', 'foo_bar', ['wrong'])],
-            'num_rows': 1,
+            "data_columns": [("item", "foo_bar", ["wrong"])],
+            "num_rows": 1,
         }
         with pytest.raises(TypeError) as excinfo:
             faker_with_foobar.json(**kwargs)
-        assert str(excinfo.value) == 'Invalid arguments type. Must be a dictionary'
+        assert str(excinfo.value) == "Invalid arguments type. Must be a dictionary"
 
     def test_json_list_format_nested_list_of_values(self, faker_with_foobar):
         kwargs = {
-            'data_columns': [
+            "data_columns": [
                 (
-                    'list', [
-                        (None, '{{ foo_bar }}s'),
-                        (None, 'foo_bar'),
+                    "list",
+                    [
+                        (None, "{{ foo_bar }}s"),
+                        (None, "foo_bar"),
                     ],
                 ),
             ],
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data['list'][0] == 'FooBars'
-        assert json_data['list'][1] == 'FooBar'
+        assert json_data["list"][0] == "FooBars"
+        assert json_data["list"][1] == "FooBar"
 
     def test_json_list_format_nested_list_of_objects(self, faker_with_foobar):
         kwargs = {
-            'data_columns': [
+            "data_columns": [
                 (
-                    'list', [
-                        ('item', '{{ foo_bar }}s'),
-                        ('item', 'foo_bar'),
+                    "list",
+                    [
+                        ("item", "{{ foo_bar }}s"),
+                        ("item", "foo_bar"),
                     ],
                 ),
             ],
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data['list'][0]['item'] == 'FooBars'
-        assert json_data['list'][1]['item'] == 'FooBar'
+        assert json_data["list"][0]["item"] == "FooBars"
+        assert json_data["list"][1]["item"] == "FooBar"
 
     def test_json_list_format_nested_objects(self, faker_with_foobar):
         kwargs = {
-            'data_columns': [
+            "data_columns": [
                 (
-                    'dict', (
-                        ('item1', '{{ foo_bar }}s'),
-                        ('item2', 'foo_bar'),
+                    "dict",
+                    (
+                        ("item1", "{{ foo_bar }}s"),
+                        ("item2", "foo_bar"),
                     ),
                 ),
             ],
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data['dict']['item1'] == 'FooBars'
-        assert json_data['dict']['item2'] == 'FooBar'
+        assert json_data["dict"]["item1"] == "FooBars"
+        assert json_data["dict"]["item2"] == "FooBar"
 
     def test_json_dict_format_nested_list_of_values(self, faker_with_foobar):
         kwargs = {
-            'data_columns': {
-                'list': [
-                    '{{ foo_bar }}s',
-                    'foo_bar',
+            "data_columns": {
+                "list": [
+                    "{{ foo_bar }}s",
+                    "foo_bar",
                 ],
             },
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data['list'][0] == 'FooBars'
-        assert json_data['list'][1] == 'FooBar'
+        assert json_data["list"][0] == "FooBars"
+        assert json_data["list"][1] == "FooBar"
 
     def test_json_dict_format_nested_list_of_objects(self, faker_with_foobar):
         kwargs = {
-            'data_columns': {
-                'list': [
-                    {'item': '{{ foo_bar }}s'},
-                    {'item': 'foo_bar'},
+            "data_columns": {
+                "list": [
+                    {"item": "{{ foo_bar }}s"},
+                    {"item": "foo_bar"},
                 ],
             },
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data['list'][0]['item'] == 'FooBars'
-        assert json_data['list'][1]['item'] == 'FooBar'
+        assert json_data["list"][0]["item"] == "FooBars"
+        assert json_data["list"][1]["item"] == "FooBar"
 
     def test_json_dict_format_nested_objects(self, faker_with_foobar):
         kwargs = {
-            'data_columns': {
-                'dict': {
-                    'item1': '{{ foo_bar }}s',
-                    'item2': 'foo_bar',
+            "data_columns": {
+                "dict": {
+                    "item1": "{{ foo_bar }}s",
+                    "item2": "foo_bar",
                 },
             },
-            'num_rows': 1,
+            "num_rows": 1,
         }
         json_data = json.loads(faker_with_foobar.json(**kwargs))
 
-        assert json_data['dict']['item1'] == 'FooBars'
-        assert json_data['dict']['item2'] == 'FooBar'
+        assert json_data["dict"]["item1"] == "FooBars"
+        assert json_data["dict"]["item2"] == "FooBar"
 
     def test_fixed_width_with_arguments(self, faker_with_foobar):
         kwargs = {
-            'data_columns': [
-                (9, '{{ foo_bar:argument_group }}'),
-                (9, 'foo_bar', {'param': 'BAR'}),
+            "data_columns": [
+                (9, "{{ foo_bar:argument_group }}"),
+                (9, "foo_bar", {"param": "BAR"}),
             ],
-            'num_rows': 2,
+            "num_rows": 2,
         }
         fixed_width_string = faker_with_foobar.fixed_width(**kwargs)
 
-        for row in fixed_width_string.split('\n'):
+        for row in fixed_width_string.split("\n"):
             assert len(row) == 18
-            assert row[0:9].strip() == 'FooBarBaz'
-            assert row[9:18].strip() == 'FooBarBAR'
+            assert row[0:9].strip() == "FooBarBaz"
+            assert row[9:18].strip() == "FooBarBAR"
 
     def test_fixed_width_invalid_arguments_type(self, faker_with_foobar):
         kwargs = {
-            'data_columns': [(9, 'foo_bar', ['wrong'])],
-            'num_rows': 1,
+            "data_columns": [(9, "foo_bar", ["wrong"])],
+            "num_rows": 1,
         }
         with pytest.raises(TypeError) as excinfo:
             faker_with_foobar.fixed_width(**kwargs)
-        assert str(excinfo.value) == 'Invalid arguments type. Must be a dictionary'
+        assert str(excinfo.value) == "Invalid arguments type. Must be a dictionary"
 
     def test_md5(self, faker):
         assert isinstance(faker.md5(), str)
